@@ -26,6 +26,7 @@
 #' @param type Type of desired formatted table, possibilities: "gt",
 #' "flextable",  and "tibble".
 #' @param groupColumn Columns to use as group labels.
+#' @param style Named list that specifies how to style the different parts of the table generated. It can either be a pre-defined style ("default" or "darwin" - the latter just for gt and flextable), NULL to get the table default style, or custom. Keep in mind that styling code is different for all table styles. To see the different styles check visOmopResults::tableStyle().
 #' @param .options Named list with additional formatting options.
 #' CohortSurvival::optionsTableSurvival() shows allowed arguments and their
 #' default values.
@@ -47,6 +48,7 @@ tableSurvival <- function(x,
                           header = c("estimate"),
                           type = "gt",
                           groupColumn = NULL,
+                          style = "default",
                           .options = list()){
 
   rlang::check_installed("visOmopResults", version = "0.5.0")
@@ -269,6 +271,7 @@ tableSurvival <- function(x,
     type = type,
     rename = renameCols,
     hide = excludeCols,
+    style = style,
     .options = c(.options, list(useFormatOrder = FALSE)) # to keep order set when factoring
   )
 
@@ -310,6 +313,7 @@ optionsTableSurvival <- function() {
 #' @param type Type of desired formatted table, possibilities: "gt",
 #' "flextable",  and "tibble".
 #' @param groupColumn Columns to use as group labels.
+#' @param style Named list that specifies how to style the different parts of the table generated. It can either be a pre-defined style ("default" or "darwin" - the latter just for gt and flextable), NULL to get the table default style, or custom. Keep in mind that styling code is different for all table styles. To see the different styles check visOmopResults::tableStyle().
 #' @param .options Named list with additional formatting options.
 #' CohortSurvival::optionsTableSurvival() shows allowed arguments and their
 #' default values.
@@ -331,6 +335,7 @@ riskTable <- function(x,
                       header = c("estimate"),
                       type = "gt",
                       groupColumn = NULL,
+                      style = "default",
                       .options = list()){
 
   rlang::check_installed("visOmopResults", version = "0.5.0")
@@ -430,6 +435,7 @@ riskTable <- function(x,
     type = type,
     rename = renameCols,
     hide = excludeCols,
+    style = style,
     .options = c(.options, list(useFormatOrder = FALSE)) # to keep order set when factoring
   )
 
