@@ -10,7 +10,7 @@ test_that("basic Survival plot", {
   )
 
   plot <- plotSurvival(surv)
-  expect_true(ggplot2::is.ggplot(plot))
+  expect_true(ggplot2::is_ggplot(plot))
 
   CDMConnector::cdmDisconnect(cdm)
 })
@@ -30,17 +30,20 @@ test_that("plot facets and colour", {
   plot <- plotSurvival(surv,
                       facet = "sex",
                       colour = "age_group")
-  expect_true(ggplot2::is.ggplot(plot))
+  expect_true(ggplot2::is_ggplot(plot))
 
   plot <- plotSurvival(surv,
                        facet = c("sex","age_group"),
                        colour = "cdm_name")
-  expect_true(ggplot2::is.ggplot(plot))
+  expect_true(ggplot2::is_ggplot(plot))
 
   plot <- plotSurvival(surv,
                        facet = "sex",
                        colour = "age_group")
-  expect_true(ggplot2::is.ggplot(plot))
+  expect_true(ggplot2::is_ggplot(plot))
+
+  expect_true(all(availableSurvivalGrouping(surv) == c("sex", "age_group", "time", "estimate",
+                                                   "estimate_95CI_lower", "estimate_95CI_upper")))
 
   CDMConnector::cdmDisconnect(cdm)
 })
@@ -57,7 +60,7 @@ test_that("basic cumulative incidence plot", {
   )
 
   plot <- plotSurvival(surv, cumulativeFailure = TRUE)
-  expect_true(ggplot2::is.ggplot(plot))
+  expect_true(ggplot2::is_ggplot(plot))
 
   survCR <- estimateCompetingRiskSurvival(cdm,
                                           targetCohortTable = "mgus_diagnosis",
@@ -66,7 +69,7 @@ test_that("basic cumulative incidence plot", {
   )
   plot <- plotSurvival(survCR, cumulativeFailure = TRUE,
                        colour = "variable")
-  expect_true(ggplot2::is.ggplot(plot))
+  expect_true(ggplot2::is_ggplot(plot))
 
   # cumulativeFailure must be true when working with competing risk result
   expect_error(plotSurvival(survCR, xscale = "years", cumulativeFailure = FALSE,
@@ -91,13 +94,19 @@ test_that("plot risk tables", {
                        colour = "age_group",
                        riskTable = TRUE)
 
-  expect_true(ggplot2::is.ggplot(plot))
+  expect_error(plotSurvival(surv,
+                            facet = "sex",
+                            colour = "age_group",
+                            riskTable = TRUE,
+                            riskInterval = 500))
+
+  expect_true(ggplot2::is_ggplot(plot))
 
   plot <- plotSurvival(surv,
                        colour = c("age_group", "sex"),
                        riskTable = TRUE)
 
-  expect_true(ggplot2::is.ggplot(plot))
+  expect_true(ggplot2::is_ggplot(plot))
 
   surv <- estimateSingleEventSurvival(cdm,
                                       targetCohortTable = "mgus_diagnosis",
@@ -108,7 +117,7 @@ test_that("plot risk tables", {
                        riskTable = TRUE,
                        riskInterval = 10)
 
-  expect_true(ggplot2::is.ggplot(plot))
+  expect_true(ggplot2::is_ggplot(plot))
 
   CDMConnector::cdmDisconnect(cdm)
 })
@@ -117,7 +126,7 @@ test_that("empty plot", {
   skip_on_cran()
   cdm <- mockMGUS2cdm()
   surv <- omopgenerics::emptySummarisedResult()
-  plotSurvival(surv)
+  expect_warning(plotSurvival(surv))
   CDMConnector::cdmDisconnect(cdm)
 })
 
@@ -133,15 +142,15 @@ test_that("timeScale parameter in plotSurvival", {
 
   # Test for days
   plot_days <- plotSurvival(surv, timeScale = "days")
-  expect_true(ggplot2::is.ggplot(plot_days))
+  expect_true(ggplot2::is_ggplot(plot_days))
 
   # Test for months
   plot_months <- plotSurvival(surv, timeScale = "months")
-  expect_true(ggplot2::is.ggplot(plot_months))
+  expect_true(ggplot2::is_ggplot(plot_months))
 
   # Test for years
   plot_years <- plotSurvival(surv, timeScale = "years")
-  expect_true(ggplot2::is.ggplot(plot_years))
+  expect_true(ggplot2::is_ggplot(plot_years))
   CDMConnector::cdmDisconnect(cdm)
 })
 
@@ -158,7 +167,7 @@ test_that("log-log survival plot", {
   )
 
   plot <- plotSurvival(surv, logLog = TRUE, cumulativeFailure = TRUE, colour = "variable")
-  expect_true(ggplot2::is.ggplot(plot))
+  expect_true(ggplot2::is_ggplot(plot))
   CDMConnector::cdmDisconnect(cdm)
 })
 
@@ -174,3 +183,13 @@ test_that("plot with bound results with different hidden inputs", {
   expect_true("follow_up_days" %in% colnames(surv_all_tidy))
   CDMConnector::cdmDisconnect(cdm)
 })
+
+test_that("expected errors for available columns", {
+  cdm <- mockMGUS2cdm()
+  surv <- estimateSingleEventSurvival(cdm, "mgus_diagnosis", "death_cohort")
+  expect_error(availableSurvivalGrouping(cdm))
+  expect_error(availableSurvivalGrouping(2))
+  expect_error(availableSurvivalGrouping(surv %>%
+                                           asSurvivalResult()))
+  expect_error(availableSurvivalGrouping(surv, "FALSE"))
+})
